class AbstractSystem(object):
    def get_cpu_temp(self) -> float:
        raise NotImplementedError('get_cpu_temp is not implemented')

    def get_cpu_percent(self) -> int:
        raise NotImplementedError('get_cpu_percent is not implemented')

    def get_disks_usage(self) -> list:
        raise NotImplementedError('get_disks_usage is not implemented')
    
    def get_ram_usage(self) -> int:
        raise NotImplementedError('get_ram_usage is not implemented')

    def halt_system(self):
        raise NotImplementedError('halt_system is not implemented')

    def reboot_system(self):
        raise NotImplementedError('reboot_system is not implemented')

    def enable_hotspot(self, password) -> bool:
        raise NotImplementedError('enable_hotspot is not implemented')

    def connect_to_ap(self, country_code, ssid, password) -> bool:
        raise NotImplementedError('connect_to_ap is not implemented')

    def get_wifi_mode(self) -> str:
        """
        Available mode are:

         - Master: acts as an access point (hotspot)
         - Managed: connects to an existing access point
        """
        raise NotImplementedError('get_wifi_mode is not implemented')
    
    def get_hw_revision(self) -> str:
        raise NotImplementedError('get_hw_revision is not implemented')
    
    def get_serial(self) -> str:
        raise NotImplementedError('get_serial is not implemented')
    
    def mount_rw(self):
        raise NotImplementedError('mount_rw is not implemented')

    def mount_ro(self):
        raise NotImplementedError('mount_ro is not implemented')

    def will_mount_rw(self) -> bool:
        raise NotImplementedError('will_mount_rw is not implemented')




from flask.app import Config

from . import AbstractCamera, AbstractIO, AbstractSystem

class ActionPiFactory(object):

    @staticmethod   
    def get_system(config: Config) -> AbstractSystem:
        if config['PLATFORM'] == 'raspberrypi':
            from .imp.raspberrypi import RaspberryPiSystem
            return RaspberryPiSystem()
        if config['PLATFORM'] == 'mock':
            from .imp.mock import MockSystem
            return MockSystem()
        else:
            raise RuntimeError('board system not supported: ' + config['PLATFORM'])

    @staticmethod
    def get_io(config: Config, camera: AbstractCamera, system: AbstractSystem) -> AbstractIO:
        if config['PLATFORM'] == 'raspberrypi':
            from .imp.raspberrypi import RaspberryPiIO
            return RaspberryPiIO(camera, system, config)
        if config['PLATFORM'] == 'mock':
            from .imp.mock import MockIO
            return MockIO(camera, system, config)
        else:
            raise RuntimeError('board system not supported: ' + config['PLATFORM'])

    @staticmethod
    def get_camera(config: Config) -> AbstractCamera:
        if config['PLATFORM'] == 'raspberrypi':
            from .imp.raspberrypi import RaspberryPiCamera
            return RaspberryPiCamera(config)
        if config['PLATFORM'] == 'mock':
            from .imp.mock import MockCamera
            return MockCamera(config)
        else:
            raise RuntimeError('board system not supported: ' + config['PLATFORM'])
